powered by
A bootstrapped confidence interval for the Maximum Likelihood Estimate for \(\psi\).
MLEp.bsci(x, level = 0.95, rounds = 1000, frac = 0.8)
A data vector.
Level of confidence interval as number between 0 and 1.
Number of bootstrap rounds. Default is 1000.
Percentage of data x used for each bootstrap round. 0.8 by default with accepted values between 0 and 1.
x
The MLE of \(\psi\) as well as lower and upper bounds of the bootstrap confidence interval.
# NOT RUN { ## Find a 95% -confidence interval for the MLE of psi given a sample from the ## Poisson-Dirichlet distribution: x<-rPD(n=10000, psi=100) MLEp.bsci(x, 0.95, 100, 0.8) # }
Run the code above in your browser using DataLab